@@ -40,6 +40,11 @@ extract(sane_import('request',
         'stay_in_ssl', 'brotherhood',
         'uri', 'login', 'cookie_test')));
 
+# Disallow redirections to other sites.
+if (strlen ($uri) < 2
+    || substr ($uri, 0, 1) !== '/' || substr ($uri, 1, 1) === '/')
+  $uri = "/";
+
 # Check cookie support.
 if (!$from_brother and !isset($_COOKIE["cookie_probe"]))
   {
@@ -154,8 +159,9 @@ if (isset($session_hash))
   {
     # Nuke their old session securely.
     session_delete_cookie('session_hash');
-    db_execute("DELETE FROM session WHERE session_hash=? AND user=?",
-               array($session_hash, $user_id));
+    if (isset ($user_id))
+      db_execute ("DELETE FROM session WHERE session_hash=? AND user=?",
+                  array($session_hash, $user_id));
   }
 
 site_header(array('title'=>_("Login")));
