@@ -4,7 +4,7 @@
 # Copyright (C) 1999-2000 The SourceForge Crew
 # Copyright (C) 2004-2005 Mathieu Roy <yeupou--gnu.org>
 # Copyright (C) 2004-2005 Joxean Koret <joxeankoret--yahoo.es>
-# Copyright (C) 2017, 2018 Ineiev <ineiev--gnu.org>
+# Copyright (C) 2017, 2018, 2019 Ineiev <ineiev--gnu.org>
 #
 # This file is part of Savane.
 #
@@ -37,8 +37,6 @@ if (user_isloggedin())
 
 # Block here potential robots.
 dnsbl_check();
-# Block banned IP.
-spam_bancheck();
 
 # CERN_SPECIFIC: here we also have a speech about AFS which must not be
 # hardcoded.
@@ -63,8 +61,17 @@ $confirm_hash = md5(strval(time()) . strval(rand()));
 $res_user = db_execute("SELECT * FROM user WHERE user_name=? AND status='A'",
                        array($form_loginname));
 if (db_numrows($res_user) < 1)
-  exit_error(_("Invalid User"),
-             _("This account does not exist or has not been activated"));
+  {
+    $res_user = db_execute("SELECT status FROM user WHERE user_name=? AND status='P'",
+                           array($form_loginname));
+    if (db_numrows($res_user) > 0)
+      $msg =
+ _("This account hasn't been activated, please contact website administration");
+    else
+      $msg = _("This account does not exist");
+
+    exit_error(_("Invalid User"), $msg);
+  }
 $row_user = db_fetch_array($res_user);
 
 # Notification count check:
@@ -150,10 +157,10 @@ $gpg_error = "";
 if(user_get_preference("email_encrypted", $row_user['user_id']))
   {
     $cmd = 'perl ../../perl/encrypt-to-user/index.pl '
-    .'--gpg=gpg '
-    .'--user="'.$row_user['user_id'].'" '
-    .'--dbname="'.$sys_dbname.'" '
-    .'--dbhost="'.$sys_dbhost.'"';
+    . '--gpg="' . $GLOBALS['sys_gpg_name'] . '" '
+    . '--user="' . $row_user['user_id'] . '" '
+    . '--dbname="' . $sys_dbname . '" '
+    . '--dbhost="' . $sys_dbhost . '"';
 
     $d_spec = array(
         0 => array("pipe", "r"), 1 => array("pipe", "w"),
