@@ -3,7 +3,7 @@
 #
 # Copyright (C) 2005-2006 Tobias Toedter <t.toedter--gmx.net>
 # Copyright (C) 2005-2006 Mathieu Roy <yeupou--gnu.org>
-# Copyright (C) 2017, 2018, 2019 Ineiev
+# Copyright (C) 2017, 2018, 2019, 2020 Ineiev
 #
 # This file is part of Savane.
 #
@@ -427,7 +427,7 @@ function markup_full($text, $allow_headings=true)
 }
 
 # Convert whatever content that can contain markup to a valid text output
-# It wont touch what seems to be valid in text already, or what cannot
+# It won't touch what seems to be valid in text already, or what cannot
 # be converted in a very satisfactory way.
 # This function should be minimal, just to avoid weird things, not to do
 # very fancy things.
@@ -798,8 +798,8 @@ function _markup_inline($line)
   # surrounding them with braces []
   # (& = begin of html entities, it means a end of string unless
   # it is &amp; which itself is the entity for &)
-  $line = preg_replace('/(^|\s|[^;\[])(('.$protocols
-                       .'):\/\/(&amp;|[^\s&]+[a-z0-9\/^])+)/i',
+  $line = preg_replace('/(^|[^;\[\/])((' . $protocols
+                       . '):\/\/(&amp;|[^\s&]+[a-z0-9\/^])+)/i',
     '$1[$2]', $line);
   # Remove spaces added with preg_replace_callback
   # and process links with preceding ';'.
@@ -900,7 +900,13 @@ function _markup_inline($line)
     # match the ending underscore and either end of line or
     # a non-word character
     .'_(\W|$)/', '$1<em>$2</em>$3', $line);
-
+  if ($GLOBALS['sys_default_domain'] != $GLOBALS['sys_file_domain'])
+    {
+      $http = session_issecure()? 'https': 'http';
+      $line = preg_replace('/<img src="\/file/',
+                           '<img src="' . $http . "://"
+                           . $GLOBALS['sys_file_domain'] . '/file', $line);
+    }
   return $line;
 }
 ?>
