@@ -113,7 +113,7 @@ if ($update_field)
     print '<form action="'.htmlentities ($_SERVER['PHP_SELF'])
           .'" method="post">';
     print '<input type="hidden" name="post_changes" value="y" />
-    <input type="hidden" name="field" value="'.htmlspeckalchars($field).'" />
+    <input type="hidden" name="field" value="'.htmlspecialchars($field).'" />
     <input type="hidden" name="group_id" value="'.htmlspecialchars($group_id).'" />
     <h1>'
       ._("Field Label:").' ';
