@@ -5,7 +5,7 @@
 # Copyright 2001-2002 Laurent Julliard, CodeX Team, Xerox
 # Copyright 2002-2006 Mathieu Roy <yeupou--gnu.org>
 # Copyright 2002-2006 Yves Perrin <yves.perrin--cern.ch>
-# Copyright 2017, 2018 Ineiev
+# Copyright 2017, 2018, 2020 Ineiev
 #
 # This file is part of Savane.
 #
@@ -37,6 +37,9 @@ $result = db_execute("SELECT * FROM " . ARTIFACT
                      . " WHERE bug_id=? AND group_id=?",
                      array($item_id, $group_id));
 
+if ($preview)
+  $field_list = trackers_extract_field_list ();
+
 if (db_numrows($result) > 0)
   {
 # Defines the item name, converting bugs to bug.
@@ -197,7 +200,7 @@ priority and open/close items"))) . "</p>\n";
 
         # Display the bug field.
         # If field size is greatest than max_size chars then force it to
-        # appear alone on a new line or it wont fit in the page.
+        # appear alone on a new line or it won't fit in the page.
 
         # Look for the field value in the database only if we missing
         # its values. If we already have a value, we are probably in
@@ -211,8 +214,15 @@ priority and open/close items"))) . "</p>\n";
           $field_value = db_result($result, 0, $field_name);
         else
           {
-            if ($preview)
-              extract(sane_import('post', array ($field_name)));
+            if ($preview && isset ($field_list[$field_name]))
+              {
+                $$field_name = $field_list[$field_name];
+                if (trackers_data_is_date_field ($field_name))
+                  {
+                    list ($yr, $mn, $dy) = preg_split ("/-/", $$field_name);
+                    $$field_name = mktime (0, 0, 0, $mn, $dy, $yr);
+                  }
+              }
             $field_value = htmlspecialchars($$field_name);
           }
         list($sz,) = trackers_data_get_display_size($field_name);
@@ -352,11 +362,8 @@ priority and open/close items"))) . "</p>\n";
     # In printer mode, deploy everything by default: assume that people default
     # printout should contain all necessary info (note that history is excluded).
     if (sane_all("printer"))
-      {
-        reset($is_deployed);
-        while (list($entry,) = each($is_deployed))
-          { $is_deployed[$entry] = true; }
-      }
+      foreach ($is_deployed as $key => $value)
+        $is_deployed[$key] = true;
 
     # If at the second step of any two-step activity (add deps, reassign,
     # multiple canned answer), deploy only the relevant:
@@ -365,9 +372,8 @@ priority and open/close items"))) . "</p>\n";
     if ($depends_search || $canned_response == "!multiple!"
         || $reassign_change_project_search)
       {
-        reset($is_deployed);
-        while (list($entry,) = each($is_deployed))
-          $is_deployed[$entry] = false;
+        foreach ($is_deployed as $key => $value)
+          $is_deployed[$key] = false;
 
         if ($depends_search)
           $is_deployed["dependencies"] = true;
@@ -602,7 +608,7 @@ of '%s' in the database:"), $depends_search);
               $artifacts = array($depends_search_only_artifact);
 
 # Actually search on each asked trackers.
-            while (list($num, $tracker) = each($artifacts))
+            foreach ($artifacts as $num => $tracker)
               {
                 if ($depends_search_only_project == "notany")
                   $GLOBALS['only_group_id'] = $group_id;
@@ -639,7 +645,7 @@ of '%s' in the database:"), $depends_search);
                            . group_getname($res_group);
                       }
                     }
-              } # while (list($num, $tracker) = each($artifacts))
+              } # foreach ($artifacts as $num => $tracker)
           } # if (strlen($depends_search) > 3)
         if (!$success)
           {
